# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.search_shared_response_messages200_response_inner import SearchSharedResponseMessages200ResponseInner

class TestSearchSharedResponseMessages200ResponseInner(unittest.TestCase):
    """SearchSharedResponseMessages200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchSharedResponseMessages200ResponseInner:
        """Test SearchSharedResponseMessages200ResponseInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchSharedResponseMessages200ResponseInner`
        """
        model = SearchSharedResponseMessages200ResponseInner()
        if include_optional:
            return SearchSharedResponseMessages200ResponseInner(
                call_id = '',
                index = 1.337,
                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                duration = 1.337,
                seconds_from_start = 1.337,
                message = '',
                role = '',
                recording_url = ''
            )
        else:
            return SearchSharedResponseMessages200ResponseInner(
                call_id = '',
                index = 1.337,
                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                duration = 1.337,
                seconds_from_start = 1.337,
                message = '',
                role = '',
        )
        """

    def testSearchSharedResponseMessages200ResponseInner(self):
        """Test SearchSharedResponseMessages200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from keplar_api.models.panel_settings import PanelSettings
from keplar_api.models.participant_create import ParticipantCreate
from typing import Optional, Set
from typing_extensions import Self

class ProjectAudience(BaseModel):
    """
    ProjectAudience
    """ # noqa: E501
    sample_size: Union[StrictFloat, StrictInt] = Field(alias="sampleSize")
    invite_title: Optional[StrictStr] = Field(default=None, alias="inviteTitle")
    invite_description: Optional[StrictStr] = Field(default=None, alias="inviteDescription")
    participants: Optional[List[ParticipantCreate]] = None
    panel_settings: Optional[PanelSettings] = Field(default=None, alias="panelSettings")
    use_public_link: Optional[StrictBool] = Field(default=None, alias="usePublicLink")
    __properties: ClassVar[List[str]] = ["sampleSize", "inviteTitle", "inviteDescription", "participants", "panelSettings", "usePublicLink"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ProjectAudience from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in participants (list)
        _items = []
        if self.participants:
            for _item_participants in self.participants:
                if _item_participants:
                    _items.append(_item_participants.to_dict())
            _dict['participants'] = _items
        # override the default output from pydantic by calling `to_dict()` of panel_settings
        if self.panel_settings:
            _dict['panelSettings'] = self.panel_settings.to_dict()
        # set to None if participants (nullable) is None
        # and model_fields_set contains the field
        if self.participants is None and "participants" in self.model_fields_set:
            _dict['participants'] = None

        # set to None if panel_settings (nullable) is None
        # and model_fields_set contains the field
        if self.panel_settings is None and "panel_settings" in self.model_fields_set:
            _dict['panelSettings'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ProjectAudience from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "sampleSize": obj.get("sampleSize"),
            "inviteTitle": obj.get("inviteTitle"),
            "inviteDescription": obj.get("inviteDescription"),
            "participants": [ParticipantCreate.from_dict(_item) for _item in obj["participants"]] if obj.get("participants") is not None else None,
            "panelSettings": PanelSettings.from_dict(obj["panelSettings"]) if obj.get("panelSettings") is not None else None,
            "usePublicLink": obj.get("usePublicLink")
        })
        return _obj





# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.invite_config import InviteConfig
from keplar_api.models.invite_status import InviteStatus
from typing import Optional, Set
from typing_extensions import Self

class Invite(BaseModel):
    """
    Invite
    """ # noqa: E501
    id: StrictStr
    name: StrictStr
    description: Optional[StrictStr] = None
    config: InviteConfig
    code: StrictStr
    status: InviteStatus
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    live_at: Optional[datetime] = Field(default=None, alias="liveAt")
    expires_at: Optional[datetime] = Field(default=None, alias="expiresAt")
    created_by_id: StrictStr = Field(alias="createdById")
    project_id: StrictStr = Field(alias="projectId")
    created_by: Optional[User] = Field(default=None, alias="createdBy")
    project: Optional[Project] = None
    calls: Optional[List[Call]] = None
    participant_invites: Optional[List[ParticipantInvite]] = Field(default=None, alias="participantInvites")
    invite_responses: Optional[List[InviteResponse]] = Field(default=None, alias="inviteResponses")
    __properties: ClassVar[List[str]] = ["id", "name", "description", "config", "code", "status", "createdAt", "updatedAt", "liveAt", "expiresAt", "createdById", "projectId", "createdBy", "project", "calls", "participantInvites", "inviteResponses"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Invite from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of config
        if self.config:
            _dict['config'] = self.config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of created_by
        if self.created_by:
            _dict['createdBy'] = self.created_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of project
        if self.project:
            _dict['project'] = self.project.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in calls (list)
        _items = []
        if self.calls:
            for _item_calls in self.calls:
                if _item_calls:
                    _items.append(_item_calls.to_dict())
            _dict['calls'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in participant_invites (list)
        _items = []
        if self.participant_invites:
            for _item_participant_invites in self.participant_invites:
                if _item_participant_invites:
                    _items.append(_item_participant_invites.to_dict())
            _dict['participantInvites'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in invite_responses (list)
        _items = []
        if self.invite_responses:
            for _item_invite_responses in self.invite_responses:
                if _item_invite_responses:
                    _items.append(_item_invite_responses.to_dict())
            _dict['inviteResponses'] = _items
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if live_at (nullable) is None
        # and model_fields_set contains the field
        if self.live_at is None and "live_at" in self.model_fields_set:
            _dict['liveAt'] = None

        # set to None if expires_at (nullable) is None
        # and model_fields_set contains the field
        if self.expires_at is None and "expires_at" in self.model_fields_set:
            _dict['expiresAt'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Invite from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "config": InviteConfig.from_dict(obj["config"]) if obj.get("config") is not None else None,
            "code": obj.get("code"),
            "status": obj.get("status"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "liveAt": obj.get("liveAt"),
            "expiresAt": obj.get("expiresAt"),
            "createdById": obj.get("createdById"),
            "projectId": obj.get("projectId"),
            "createdBy": User.from_dict(obj["createdBy"]) if obj.get("createdBy") is not None else None,
            "project": Project.from_dict(obj["project"]) if obj.get("project") is not None else None,
            "calls": [Call.from_dict(_item) for _item in obj["calls"]] if obj.get("calls") is not None else None,
            "participantInvites": [ParticipantInvite.from_dict(_item) for _item in obj["participantInvites"]] if obj.get("participantInvites") is not None else None,
            "inviteResponses": [InviteResponse.from_dict(_item) for _item in obj["inviteResponses"]] if obj.get("inviteResponses") is not None else None
        })
        return _obj

from keplar_api.models.call import Call
from keplar_api.models.invite_response import InviteResponse
from keplar_api.models.participant_invite import ParticipantInvite
from keplar_api.models.project import Project
from keplar_api.models.user import User
# TODO: Rewrite to not use raise_errors
Invite.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from keplar_api.models.invite_customer_item import InviteCustomerItem
from typing import Optional, Set
from typing_extensions import Self

class InviteCustomersRequest(BaseModel):
    """
    InviteCustomersRequest
    """ # noqa: E501
    customers: Annotated[List[InviteCustomerItem], Field(min_length=1, max_length=50)]
    org_name: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=200)]] = Field(default=None, alias="orgName")
    is2_fa_enabled: Optional[StrictBool] = Field(default=None, alias="is2FAEnabled")
    default_workspace_id: Optional[StrictStr] = Field(default=None, alias="defaultWorkspaceId")
    create_default_workspace: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=200)]] = Field(default=None, alias="createDefaultWorkspace")
    additional_workspace_ids: Optional[List[StrictStr]] = Field(default=None, alias="additionalWorkspaceIds")
    __properties: ClassVar[List[str]] = ["customers", "orgName", "is2FAEnabled", "defaultWorkspaceId", "createDefaultWorkspace", "additionalWorkspaceIds"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of InviteCustomersRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in customers (list)
        _items = []
        if self.customers:
            for _item_customers in self.customers:
                if _item_customers:
                    _items.append(_item_customers.to_dict())
            _dict['customers'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of InviteCustomersRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "customers": [InviteCustomerItem.from_dict(_item) for _item in obj["customers"]] if obj.get("customers") is not None else None,
            "orgName": obj.get("orgName"),
            "is2FAEnabled": obj.get("is2FAEnabled"),
            "defaultWorkspaceId": obj.get("defaultWorkspaceId"),
            "createDefaultWorkspace": obj.get("createDefaultWorkspace"),
            "additionalWorkspaceIds": obj.get("additionalWorkspaceIds")
        })
        return _obj





# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.update_call_for_code_invite_response_request import UpdateCallForCodeInviteResponseRequest

class TestUpdateCallForCodeInviteResponseRequest(unittest.TestCase):
    """UpdateCallForCodeInviteResponseRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateCallForCodeInviteResponseRequest:
        """Test UpdateCallForCodeInviteResponseRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateCallForCodeInviteResponseRequest`
        """
        model = UpdateCallForCodeInviteResponseRequest()
        if include_optional:
            return UpdateCallForCodeInviteResponseRequest(
                call_id = '',
                call = keplar_api.models.update_call_for_code_invite_response_request_call.updateCallForCodeInviteResponse_request_call(
                    vendor_call_id = '', 
                    status = 'REQUESTED', )
            )
        else:
            return UpdateCallForCodeInviteResponseRequest(
                call_id = '',
                call = keplar_api.models.update_call_for_code_invite_response_request_call.updateCallForCodeInviteResponse_request_call(
                    vendor_call_id = '', 
                    status = 'REQUESTED', ),
        )
        """

    def testUpdateCallForCodeInviteResponseRequest(self):
        """Test UpdateCallForCodeInviteResponseRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.get_workspace_members200_response import GetWorkspaceMembers200Response

class TestGetWorkspaceMembers200Response(unittest.TestCase):
    """GetWorkspaceMembers200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetWorkspaceMembers200Response:
        """Test GetWorkspaceMembers200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetWorkspaceMembers200Response`
        """
        model = GetWorkspaceMembers200Response()
        if include_optional:
            return GetWorkspaceMembers200Response(
                items = [
                    keplar_api.models.workspace_member_item.WorkspaceMemberItem(
                        id = '', 
                        user_id = '', 
                        role = '', 
                        user = keplar_api.models.workspace_member_user.WorkspaceMemberUser(
                            id = '', 
                            name = '', 
                            email = '', ), 
                        created_at = '', )
                    ]
            )
        else:
            return GetWorkspaceMembers200Response(
                items = [
                    keplar_api.models.workspace_member_item.WorkspaceMemberItem(
                        id = '', 
                        user_id = '', 
                        role = '', 
                        user = keplar_api.models.workspace_member_user.WorkspaceMemberUser(
                            id = '', 
                            name = '', 
                            email = '', ), 
                        created_at = '', )
                    ],
        )
        """

    def testGetWorkspaceMembers200Response(self):
        """Test GetWorkspaceMembers200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
